==> seui-cli-2.4.1.tgz: package/README.md <==
# seui-cli

> seui-cli 是 配合 seui 框架使用的命令行工具

# 命令行使用

## 1、安装

```bash
npm i seui-cli -g
```

如果出现`permission denied`等相关权限的错误提示，请使用管理员身份或root身份运行，如 mac：`sudo npm i seui-cli -g`。

## 2、更新

```bash
npm update seui-cli -g
```

## 3、使用


#### 3-1、创建应用

```bash
seui create [projectName]
```

- projectName: 工程名称（选题，默认：`seui-demo`）

#### 3-2、项目主框架升级至最新版本

```bash
seui update
```

#### 3-3、调试开发

```bash
seui dev
```

#### 3-4、编译构造

```bash
seui build
```

#### 3-5、创建vue页面示例模板

```bash
seui vue [pageName]
```

- pageName: 页面名称

#### 3-6、安装插件

```bash
seui plugin [command] [pluginName]
```

- command: 命令（安装：`install`，卸载：`uninstall`，修复：`repair`，创建：`create`，发布：`publish`）
- pluginName: 插件名称（插件列表可以查看[https://seui.app/markets/](https://seui.app/markets/)）
- command为`repair`时pluginName可留空。

```
//安装插件示例：
seui plugin install pay

//卸载插件示例：
seui plugin uninstall pay

//修复插件示例：
seui plugin repair

//创建插件示例：
seui plugin create pluginDemo

//发布插件示例：
seui plugin publish pluginDemo
```

#### 3-7、App设置（应用名称、版本等）

```bash
seui setting
```

#### 3-8、设置App模板（初始化演示模板）

```bash
seui setdemo
```

#### 3-9、一键云修复文件（热更新）

```bash
seui repair
```

#### 3-10、一键设置应用图标

```bash
seui icons [id]
```

- id: 图标资源ID，生成地址：[https://console.seui.app/#/tools/icons](https://console.seui.app/#/tools/icons)

#### 3-11、一键设置应用启动图

```bash
seui launchimage [id]
```

- id: 启动图资源ID，生成地址：[https://console.seui.app/#/tools/launchimage](https://console.seui.app/#/tools/launchimage)

#### 3-12、登录云中心

```bash
seui login
```

#### 3-13、登出云中心

```bash
seui logout
```

#### 3-14、备份项目开发文件

```bash
seui backup
```

#### 3-15、恢复项目开发文件

```bash
seui recovery
```

## 4、版本及帮助

```bash
seui -v    // 查看当前cli版本
seui -h    // 命令帮助信息
```

==> seui-cli-2.4.2.tgz: package/README.md <==
# seui-cli

> seui-cli 是 配合 seui 框架使用的命令行工具

# 命令行使用

## 1、安装

```bash
npm i seui-cli -g
```

如果出现`permission denied`等相关权限的错误提示，请使用管理员身份或root身份运行，如 mac：`sudo npm i seui-cli -g`。

## 2、更新

```bash
npm update seui-cli -g
```

## 3、使用


#### 3-1、创建应用

```bash
seui create [projectName]
```

- projectName: 工程名称（选题，默认：`seui-demo`）

#### 3-2、项目主框架升级至最新版本

```bash
seui update
```

#### 3-3、调试开发

```bash
seui dev
```

#### 3-4、编译构造

```bash
seui build
```

#### 3-5、创建vue页面示例模板

```bash
seui vue [pageName]
```

- pageName: 页面名称

#### 3-6、安装插件

```bash
seui plugin [command] [pluginName]
```

- command: 命令（安装：`install`，卸载：`uninstall`，修复：`repair`，创建：`create`，发布：`publish`）
- pluginName: 插件名称（插件列表可以查看[gitlab](http://192.168.1.61/seetech/seui)）
- command为`repair`时pluginName可留空。

```
//安装插件示例：
seui plugin install pay

//卸载插件示例：
seui plugin uninstall pay

//修复插件示例：
seui plugin repair

//创建插件示例：
seui plugin create pluginDemo

//发布插件示例：
seui plugin publish pluginDemo
```

#### 3-7、App设置（应用名称、版本等）

```bash
seui setting
```

#### 3-8、设置App模板（初始化演示模板）

```bash
seui setdemo
```

#### 3-9、一键云修复文件（热更新）

```bash
seui repair
```

#### 3-10、一键设置应用图标

```bash
seui icons [id]
```

- id: 图标资源ID，生成地址：[点击前往](https://console.seui.app/#/tools/icons)

#### 3-11、一键设置应用启动图

```bash
seui launchimage [id]
```

- id: 启动图资源ID，生成地址：[点击前往](https://console.seui.app/#/tools/launchimage)

#### 3-12、登录云中心

```bash
seui login
```

#### 3-13、登出云中心

```bash
seui logout
```

#### 3-14、备份项目开发文件

```bash
seui backup
```

#### 3-15、恢复项目开发文件

```bash
seui recovery
```

## 4、版本及帮助

```bash
seui -v    // 查看当前cli版本
seui -h    // 命令帮助信息
```
